==> icedove-dispmua_1.5.4.orig.tar.gz: icedove-dispmua-1.5.4/chrome/content/data-77.js <==
//  "webmail" : [ "1und1.png" , "http://www.1und1.de/" ] , // and others!
dispMUA.arDispMUAAllocation["w"] =
{
  "www.talkaboutsportsnetwork.com" : [ "tasn.png" ] ,
  "www-mail (funpic portal)" : [ "funpic_de.png" , "http://www.funpic.de/" ] ,
  "www.20minutos.es mailer" : [ "20minutos_es.png" , "http://www.20minutos.es/" ] ,
  "woodstone servers alive" : [ "salive.png" ] ,
  "waste.uk.com mailsystem" : [ "waste.uk.com.png" , "http://www.waste.uk.com/" ] ,
  "wr-subscribe mailer" : [ "wr-scripts.png" , "http://wr.kovostok.ru/" ] ,
  "www.virtusales.com" : [ "virtusales_com.png" , "http://www.virtusales.com/" ] ,
  "www.mynewsgate.net" : [ "mynewsgate_net.png" , "http://www.mynewsgate.net/" ] ,
  "www.cleverreach.de" : [ "cleverreach_de.png" , "http://www.cleverreach.de/" ] ,
  "webmail.osnanet.de" : [ "osnatel_de.png" , "http://www.osnanet.de/" ] ,
  "www.bhsbinkert.de" : [ "bhsbinkert.png" , "http://www.bhsbinkert.de/" ] ,
  "woltlab community" : [ "wbb.png" , "http://community.woltlab.com/" ] ,
  "webmail mirapoint" : [ "mirapoint.png" ] ,
  "webmail di libero" : [ "libero_it.png" , "http://liberomail.libero.it/" ] ,
  "www.schworak.com" : [ "schworak.png" ] ,
  "wordperfect mail" : [ "wordperfect.png" ] ,
  "webmail-email.it" : [ "email_it.png" , "http://www.email.it/" ] ,
  "web based pronto" : [ "web_based_pronto.png" ] ,
  "www.webspace.de" : [ "webspace_de.png" , "http://www.webspace.de/" ] ,
  "www.titulky.com" : [ "titulky_com.png" , "http://www.titulky.com/" ] ,
  "www.newsland.it" : [ "newsland_it.png" , "http://www.newsland.it/" ] ,
  "webnews to mail" : [ "netwinsite.png" , "http://netwinsite.com/webnews/" ] ,
  "webmail version" : [ "webmail.png" ] ,
  "web4u csendmail" : [ "web4u.png" , "http://www.web4u.cz/" ] ,
  "web-based email" : [ "godaddy.png" ] ,
  "www.mailpro.pl" : [ "mailpro_pl.png" , "http://www.mailpro.pl/" ] ,
  "windows eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "webmasterworld" : [ "webmasterworld.png" ] ,
  "webmail rol.ro" : [ "rol_ro.png" , "http://www.rol.ro/" ] ,
  "webedition cms" : [ "webedition.png" , "http://www.webedition.de/" ] ,
  "www.heycom.de" : [ "heycom_de.png" , "http://www.heycom.de/" ] ,
  "winehq mailer" : [ "winehq.png" , "http://www.winehq.org/" ] ,
  "wg-gesucht.de" : [ "wg-gesucht_de.png" , "http://www.wg-gesucht.de/" ] ,
  "webreport/400" : [ "webreport-400.png" , "http://www.kisco.com/webreport/" ] ,
  "www.4free.pl" : [ "4free_pl.png" , "http://www.4free.pl/" ] ,
  "winnt's blat" : [ "blat.png" , "http://www.blat.net/" ] ,
  "webalta-mail" : [ "webalta.png" , "http://www.webalta.ru/" ] ,
  "worldclient" : [ "worldclient.png" ] ,
  "winnt's msm" : [ "msm.png" ] ,
  "websurveyor" : [ "vovici.png" , "http://www.websurveyor.com/" ] ,
  "webroot.com" : [ "webroot_com.png" , "http://www.webroot.com/" ] ,
  "webmail ulb" : [ "ulb.png" ] ,
  "web de mail" : [ "web_de_mail.png" ] ,
  "wongmailer" : [ "wongmailer.png" , "http://www.mister-wong.com/" ] ,
  "whatcounts" : [ "whatcounts.png" ] ,
  "wanderlust" : [ "wanderlust.png" ] ,
  "west wind" : [ "westwind.png" ] ,
  "webmail6." : [ "webmail_us.png" , "http://www.mailtrust.com/" ] ,
  "wdcollect" : [ "plesk.png" , "http://www.parallels.com/plesk/" ] ,
  "windmail" : [ "windmail.png" ] ,
  "wemail32" : [ "wemail.png" ] ,
  "web-news" : [ "web-news.png" , "http://web-news.sourceforge.net/" ] ,
  "wamailer" : [ "wamailer.png" ] ,
  "writely" : [ "writely.png" ] ,
  "winbiff" : [ "winbiff.png" ] ,
  "webmin" : [ "webmin.png" , "http://www.webmin.com/" ] ,
  "webcit" : [ "webcit.png" , "http://www.citadel.org/" ] ,
  "winvn" : [ "winvn.png" ] ,
  "wbb" : [ "wbb.png" , "http://www.woltlab.de/" ] ,
}

==> icedove-dispmua_1.6.0.orig.tar.gz: icedove-dispmua-1.6.0/chrome/content/data-77.js <==
//  "webmail" : [ "1und1.png" , "http://www.1und1.de/" ] , // conflicts with others!
dispMUA.arDispMUAAllocation["w"] =
{
  "www.talkaboutsportsnetwork.com" : [ "tasn.png" ] ,
  "windows sharepoint services" : [ "ms_sharepoint.png" , "http://www.microsoft.com/" ] ,
  "webmail (1und1 webmailer)" : [ "1und1.png" , "http://www.1und1.de/" ] ,
  "www-mail (funpic portal)" : [ "funpic_de.png" , "http://www.funpic.de/" ] ,
  "www.20minutos.es mailer" : [ "20minutos_es.png" , "http://www.20minutos.es/" ] ,
  "woodstone servers alive" : [ "salive.png" ] ,
  "waste.uk.com mailsystem" : [ "waste.uk.com.png" , "http://www.waste.uk.com/" ] ,
  "wr-subscribe mailer" : [ "wr-scripts.png" , "http://wr.kovostok.ru/" ] ,
  "www.virtusales.com" : [ "virtusales_com.png" , "http://www.virtusales.com/" ] ,
  "www.mynewsgate.net" : [ "mynewsgate_net.png" , "http://www.mynewsgate.net/" ] ,
  "www.cleverreach.de" : [ "cleverreach_de.png" , "http://www.cleverreach.de/" ] ,
  "webmail.osnanet.de" : [ "osnatel_de.png" , "http://www.osnanet.de/" ] ,
  "www.bhsbinkert.de" : [ "bhsbinkert.png" , "http://www.bhsbinkert.de/" ] ,
  "woltlab community" : [ "wbb.png" , "http://community.woltlab.com/" ] ,
  "webmail mirapoint" : [ "mirapoint.png" ] ,
  "webmail di libero" : [ "libero_it.png" , "http://liberomail.libero.it/" ] ,
  "www.schworak.com" : [ "schworak.png" ] ,
  "wordperfect mail" : [ "wordperfect.png" ] ,
  "webmail-email.it" : [ "email_it.png" , "http://www.email.it/" ] ,
  "web based pronto" : [ "web_based_pronto.png" ] ,
  "www.webspace.de" : [ "webspace_de.png" , "http://www.webspace.de/" ] ,
  "www.titulky.com" : [ "titulky_com.png" , "http://www.titulky.com/" ] ,
  "www.newsland.it" : [ "newsland_it.png" , "http://www.newsland.it/" ] ,
  "webnews to mail" : [ "netwinsite.png" , "http://netwinsite.com/webnews/" ] ,
  "webmail version" : [ "webmail.png" ] ,
  "web4u csendmail" : [ "web4u.png" , "http://www.web4u.cz/" ] ,
  "web-based email" : [ "godaddy.png" ] ,
  "www.mailpro.pl" : [ "mailpro_pl.png" , "http://www.mailpro.pl/" ] ,
  "windows eudora" : [ "eudora.png" , "http://www.eudora.com/" ] ,
  "webmasterworld" : [ "webmasterworld.png" ] ,
  "webmail rol.ro" : [ "rol_ro.png" , "http://www.rol.ro/" ] ,
  "webedition cms" : [ "webedition.png" , "http://www.webedition.de/" ] ,
  "www.heycom.de" : [ "heycom_de.png" , "http://www.heycom.de/" ] ,
  "winehq mailer" : [ "winehq.png" , "http://www.winehq.org/" ] ,
  "wg-gesucht.de" : [ "wg-gesucht_de.png" , "http://www.wg-gesucht.de/" ] ,
  "webreport/400" : [ "webreport-400.png" , "http://www.kisco.com/webreport/" ] ,
  "www.4free.pl" : [ "4free_pl.png" , "http://www.4free.pl/" ] ,
  "winnt's blat" : [ "blat.png" , "http://www.blat.net/" ] ,
  "webalta-mail" : [ "webalta.png" , "http://www.webalta.ru/" ] ,
  "worldclient" : [ "worldclient.png" ] ,
  "winnt's msm" : [ "msm.png" ] ,
  "websurveyor" : [ "vovici.png" , "http://www.websurveyor.com/" ] ,
  "webroot.com" : [ "webroot_com.png" , "http://www.webroot.com/" ] ,
  "webmail ulb" : [ "ulb.png" ] ,
  "web de mail" : [ "web_de_mail.png" ] ,
  "wongmailer" : [ "wongmailer.png" , "http://www.mister-wong.com/" ] ,
  "whatcounts" : [ "whatcounts.png" ] ,
  "wanderlust" : [ "wanderlust.png" ] ,
  "west wind" : [ "westwind.png" ] ,
  "webmail6." : [ "webmail_us.png" , "http://www.mailtrust.com/" ] ,
  "wdcollect" : [ "plesk.png" , "http://www.parallels.com/plesk/" ] ,
  "windmail" : [ "windmail.png" ] ,
  "wemail32" : [ "wemail.png" ] ,
  "web-news" : [ "web-news.png" , "http://web-news.sourceforge.net/" ] ,
  "wamailer" : [ "wamailer.png" ] ,
  "writely" : [ "writely.png" ] ,
  "winbiff" : [ "winbiff.png" ] ,
  "webmin" : [ "webmin.png" , "http://www.webmin.com/" ] ,
  "webcit" : [ "webcit.png" , "http://www.citadel.org/" ] ,
  "winvn" : [ "winvn.png" ] ,
  "whups" : [ "horde.png" , "http://www.horde.org/whups/" ] ,
  "wbb" : [ "wbb.png" , "http://www.woltlab.de/" ] ,
}
